**pingparsing**

.. image:: https://travis-ci.org/thombashi/pingparsing.svg?branch=master
    :target: https://travis-ci.org/thombashi/pingparsing
.. image:: https://ci.appveyor.com/api/projects/status/h5wqaowr2lql5yy6?svg=true
    :target: https://ci.appveyor.com/project/thombashi/pingparsing

.. contents:: Table of contents
   :backlinks: top
   :local:
